"""
The crochetcalculator package
"""

#__init__.py

# Version of the crochet-calculator package
__version__ = "0.0.4"

# Modules
from .gauge import calculate_gauge